﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Reflection;
using System.Windows;
using System.Windows.Controls.Primitives;
using System.Windows.Forms;
using MapInfo.Data;
using MapInfo.Types;
using MapInfo.Types.Data;
using static EnviroRisk.TableHelper;

namespace EnviroRisk
{
    public class EnviroRiskAddIn : EnviroRiskAddInInterface
    {
        static public IMapBasicApplication MBA;
        static public IMapInfoPro MapInfoApplication_;
        protected IMapInfoPro MapInfoApplication;
        private IRibbonTab exampleTab;

        public static void Debug(string msg)
        {
            lock (MapInfoApplication_)
            {
                string file = "data/log.log";
                File.AppendAllText(file, msg + Environment.NewLine + Environment.NewLine);
            }
        }

        public void Initialize(IMapInfoPro mapInfoApplication, string mbxname)
        {
            UriParser.Register(new GenericUriParser(GenericUriParserOptions.GenericAuthority), "pack", -1);
            
            MapInfoApplication = mapInfoApplication;
            ThisApplication = MapInfoApplication.GetMapBasicApplication(mbxname);
            MBA = ThisApplication;
            MapInfoApplication_ = MapInfoApplication;
            AddRibbonTab();
        }

        static public System.Uri getLocalResourceUri(string name)
        {
            string codeBase = Assembly.GetExecutingAssembly().CodeBase;
            UriBuilder uri = new UriBuilder(codeBase);
            string path = Uri.UnescapeDataString(uri.Path);
            return PathToUri("pack://addinorigin:,,,/" + Uri.EscapeUriString(path) + ";component"+name);
        }

        static public string getLocalResourcePath(string name)
        {
            string codeBase = Assembly.GetExecutingAssembly().CodeBase;
            Uri uri = new Uri(Path.GetDirectoryName(codeBase));

            string path = Path.Combine(uri.AbsolutePath, name);
            return path;
        }

        private void AddRibbonTab()
        {
            exampleTab = MapInfoApplication.Ribbon.Tabs.Add("BadExample", "EXAMPLE");

            if (exampleTab == null) return;

            exampleTab.KeyTip = "ET";

            {
                var controlsGroup = exampleTab.Groups.Add("ClickThatButton", "Do something");
                if (controlsGroup == null) return;
                //Add download button
                {
                    var downloadButton = controlsGroup.Controls.Add("MyButton", "Load and interpolate data") as IRibbonButtonControl;
                    if (downloadButton == null) return;
                    downloadButton.KeyTip = "MB";
                    downloadButton.IsLarge = true;
                    //downloadButton.LargeIcon = getLocalResourceUri("/IMG/more32.png");
                    //downloadButton.SmallIcon = getLocalResourceUri("/IMG/more16.png");
                    downloadButton.Command = new DelegateCommand(Example).ViewToContractAdapter();
                }
            }
        }

        void Example(object param)
        {
            Debug("Showing download dialog");
            try
            {
                PointTable newTable = new PointTable("data/data.tab");
                newTable.writeRaster("data/raster.mrr");
                TableHelper.OpenTable("data/raster.tab");
            }
            catch (Exception e)
            {
                Debug(e.ToString());
            }       
        }

        void OnEndApplication(object sender)
        {
            if (ThisApplication != null)
            {
                ThisApplication.EndApplication();
            }
        }

        public virtual void Unload()
        {
			UnloadRibbonTab();
			exampleTab = null;
		}

		private void UnloadRibbonTab()
		{
			MapInfoApplication.Ribbon.Tabs.Remove(exampleTab);
		}

        public IMapBasicApplication ThisApplication { get; set; }

		public static Uri PathToUri(string uri)
		{
			try
			{
				return new Uri(uri, UriKind.RelativeOrAbsolute);
			}
			catch (Exception)
			{
				return null;
			}
		}
	}
}
